rai\_toolbox.optim.ChainedParamTransformingOptimizer
====================================================

.. currentmodule:: rai_toolbox.optim

.. autoclass:: ChainedParamTransformingOptimizer

   
   .. automethod:: __init__
   
   .. rubric:: Methods

   .. autosummary::
   
      ~ChainedParamTransformingOptimizer.__init__